@@ -1,22 +1,5 @@
 import pandas as pd
 
-from .inference_functions import (
-    boolean_func,
-    boolean_nullable_func,
-    categorical_func,
-    datetime_func,
-    double_func,
-    email_address_func,
-    integer_func,
-    integer_nullable_func,
-    ip_address_func,
-    natural_language_func,
-    phone_number_func,
-    postal_code_func,
-    timedelta_func,
-    url_func,
-)
-
 from woodwork.accessor_utils import _is_dask_series, _is_spark_series
 from woodwork.logical_types import (
     URL,
@@ -46,6 +29,23 @@ from woodwork.logical_types import (
     SubRegionCode,
     Timedelta,
     Unknown,
+    _replace_nans,
+)
+from woodwork.type_sys.inference_functions import (
+    boolean_func,
+    boolean_nullable_func,
+    categorical_func,
+    datetime_func,
+    double_func,
+    email_address_func,
+    integer_func,
+    integer_nullable_func,
+    ip_address_func,
+    natural_language_func,
+    phone_number_func,
+    postal_code_func,
+    timedelta_func,
+    url_func,
 )
 
 DEFAULT_INFERENCE_FUNCTIONS = {
@@ -98,7 +98,10 @@ INFERENCE_SAMPLE_SIZE = 100000
 
 class TypeSystem(object):
     def __init__(
-        self, inference_functions=None, relationships=None, default_type=DEFAULT_TYPE
+        self,
+        inference_functions=None,
+        relationships=None,
+        default_type=DEFAULT_TYPE,
     ):
         """Create a new TypeSystem object. LogicalTypes that are present in the keys of
         the inference_functions dictionary will be considered registered LogicalTypes.
@@ -154,7 +157,7 @@ class TypeSystem(object):
         registered_ltype_names = [ltype.__name__ for ltype in self.registered_types]
         if logical_type.__name__ in registered_ltype_names:
             raise ValueError(
-                f"Logical Type with name {logical_type.__name__} already present in the Type System. Please rename the LogicalType or remove existing one."
+                f"Logical Type with name {logical_type.__name__} already present in the Type System. Please rename the LogicalType or remove existing one.",
             )
         self.update_inference_function(logical_type, inference_function)
         if parent:
@@ -198,7 +201,8 @@ class TypeSystem(object):
         if isinstance(logical_type, str):
             logical_type = self.str_to_logical_type(logical_type)
         self._validate_type_input(
-            logical_type=logical_type, inference_function=inference_function
+            logical_type=logical_type,
+            inference_function=inference_function,
         )
         self.inference_functions[logical_type] = inference_function
 
@@ -266,7 +270,10 @@ class TypeSystem(object):
         return depth
 
     def _validate_type_input(
-        self, logical_type=None, inference_function=None, parent=None
+        self,
+        logical_type=None,
+        inference_function=None,
+        parent=None,
     ):
         if logical_type and logical_type not in LogicalType.__subclasses__():
             raise TypeError("logical_type must be a valid LogicalType")
@@ -296,7 +303,7 @@ class TypeSystem(object):
                 series = series.head(INFERENCE_SAMPLE_SIZE).to_pandas()
             else:
                 raise ValueError(
-                    f"Unsupported series type `{type(series)}`"
+                    f"Unsupported series type `{type(series)}`",
                 )  # pragma: no cover
 
             # For dask or spark collections, unknown type special case comes
@@ -325,8 +332,11 @@ class TypeSystem(object):
         types_to_check = [
             ltype for ltype in self.root_types if ltype != NaturalLanguage
         ]
-        type_matches = get_inference_matches(types_to_check, series)
+        series_nan_cast = _replace_nans(series)  # Will change dtype
+        if series_nan_cast.count() == 0:
+            return Unknown()
 
+        type_matches = get_inference_matches(types_to_check, series_nan_cast)
         if len(type_matches) == 0:
             # Check if this is NaturalLanguage, otherwise set
             # type to default type (Unknown). Assume that a column
@@ -335,7 +345,7 @@ class TypeSystem(object):
             # limiting the times the natural language inference function
             # is called.
             if self.inference_functions.get(
-                NaturalLanguage
+                NaturalLanguage,
             ) and self.inference_functions[NaturalLanguage](series):
                 logical_type = NaturalLanguage
             else:
@@ -347,7 +357,12 @@ class TypeSystem(object):
             # If multiple matches, get the most specific one. If multiple
             # matches have the same level of specificity, the first
             # match found at that level will be returned
-            best_match = type_matches[0]
+            if (
+                Categorical in type_matches or Double in type_matches
+            ) and IntegerNullable in type_matches:
+                best_match = IntegerNullable
+            else:
+                best_match = type_matches[0]
             best_depth = self._get_depth(best_match)
             for logical_type in type_matches[1:]:
                 ltype_depth = self._get_depth(logical_type)
