@@ -69,7 +69,7 @@ def _is_numeric_series(series, logical_type):
 
         # Allow numeric columns to be interpreted as Datetimes - doesn't allow strings even if they could be numeric
         if _get_ltype_class(
-            logical_type
+            logical_type,
         ) == ww.logical_types.Datetime and pd.api.types.is_numeric_dtype(series):
             return True
     else:
@@ -101,7 +101,7 @@ def list_logical_types():
                 "parent_type": ww.type_system._get_parent(ltype),
             }
             for ltype in ww.logical_types.LogicalType.__subclasses__()
-        ]
+        ],
     )
     return ltypes_df.sort_values("name").reset_index(drop=True)
 
@@ -127,7 +127,7 @@ def list_semantic_tags():
         [
             {"name": tag, "is_standard_tag": True, "valid_logical_types": sem_tags[tag]}
             for tag in sem_tags
-        ]
+        ],
     )
     tags_df = tags_df.append(
         pd.DataFrame(
